@@ -18,7 +18,7 @@
  *
  * May, 2000. Implemented on FreeBSD 4.0-RELEASE (Compaq Armada M700)
  *
- $Id: battstat_applet.c,v 1.46 2002/12/09 00:44:31 kevinv Exp $
+ $Id: battstat_applet.c,v 1.47 2003/01/22 07:46:05 arvind Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -668,7 +668,10 @@ destroy_applet (GtkWidget *widget, gpointer data)
    ProgressData *pdata = data;
    
    if (DEBUG) g_print("destroy_applet()\n");
-   
+
+   if (pdata->prop_win)
+	gtk_widget_destroy (GTK_WIDGET (pdata->prop_win));
+
    gtk_timeout_remove (pdata->pixtimer);
    pdata->pixtimer = 0;
    pdata->applet = NULL;
