@@ -24,6 +24,7 @@
 #include <libgnome/libgnome.h>
 #include <libgnomeui/libgnomeui.h>
 #include <panel-applet.h>
+#include <egg-screen-exec.h>
 
 #include "drivemount.h"
 #include "properties.h"
@@ -385,7 +386,8 @@ browse_cb (BonoboUIComponent *uic,
 		return;
 
 	command = g_strdup_printf ("nautilus %s", drivemount->mount_point);
-	g_spawn_command_line_async (command, &error);
+	egg_screen_execute_command_line_async (
+		gtk_widget_get_screen (drivemount->applet), command, &error);
 	g_free (command);
 	if (error) {
 		GtkWidget *dialog;
@@ -403,6 +405,8 @@ browse_cb (BonoboUIComponent *uic,
 				  NULL);
 
 		gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
+		gtk_window_set_screen (GTK_WINDOW (dialog),
+				       gtk_widget_get_screen (drivemount->applet));
 
 		gtk_widget_show (dialog);
 
@@ -449,6 +453,8 @@ about_cb (BonoboUIComponent *uic,
 	const gchar *translator_credits = _("translator_credits");
 
 	if (about) {
+		gtk_window_set_screen (GTK_WINDOW (about),
+				       gtk_widget_get_screen (drivemount->applet));
 		gtk_window_present (GTK_WINDOW (about));
 		return;
 	}
@@ -474,6 +480,8 @@ about_cb (BonoboUIComponent *uic,
    		gdk_pixbuf_unref (pixbuf);
    
    	gtk_window_set_wmclass (GTK_WINDOW (about), "disk mounter", "Disk Mounter");
+	gtk_window_set_screen (GTK_WINDOW (about),
+			       gtk_widget_get_screen (drivemount->applet));
    	g_signal_connect (G_OBJECT (about), "destroy",
 			  G_CALLBACK (gtk_widget_destroyed), &about);
 	gtk_widget_show (about);
@@ -730,6 +738,8 @@ mount_cb (GtkWidget *widget,
 
 	/* Stop the user from displaying zillions of error messages */
 	if (dd->error_dialog) {
+		gtk_window_set_screen (GTK_WINDOW (dd->error_dialog),
+				       gtk_widget_get_screen (dd->applet));
 		gtk_window_present (GTK_WINDOW (dd->error_dialog));
 		return;
 	}
@@ -777,6 +787,8 @@ mount_cb (GtkWidget *widget,
 						     NULL, GTK_DIALOG_MODAL,
 						     GTK_STOCK_OK,
 						     GTK_RESPONSE_OK, NULL);
+		gtk_window_set_screen (GTK_WINDOW (dd->error_dialog),
+				       gtk_widget_get_screen (dd->applet));
 		hbox = gtk_hbox_new (FALSE, 0);
 		gtk_box_pack_start (GTK_BOX
 				    (GTK_DIALOG (dd->error_dialog)->vbox), hbox,
