@@ -324,7 +324,7 @@ static gboolean
 row_activated_cb (GtkWidget *widget, GdkEventButton *event, gpointer data)
 {
   GkbPropertyBoxInfo * pbi = data;
-  
+
   if (event->type == GDK_2BUTTON_PRESS) {
   	addwadd_cb (NULL, pbi);
   	return TRUE;
@@ -334,6 +334,21 @@ row_activated_cb (GtkWidget *widget, GdkEventButton *event, gpointer data)
   
 }
 
+static void
+addbutton_sensitive_cb (GtkTreeView * treeview, gpointer data)
+{
+  GkbPropertyBoxInfo * pbi = data;
+  GKB * gkb = pbi->gkb;
+  GtkWidget * addbutton = gtk_object_get_data (GTK_OBJECT (gkb->addwindow), "addbutton");
+
+  if (pbi->keymap_for_add->command != NULL) {
+    gtk_widget_set_sensitive (addbutton, TRUE);
+  } else {
+    gtk_widget_set_sensitive (addbutton, FALSE);
+  }
+
+}
+
 static void
 response_cb (GtkDialog *dialog, gint id, gpointer data)
 {
@@ -361,6 +376,7 @@ gkb_prop_map_add (GkbPropertyBoxInfo * pbi)
 {
   GtkWidget *vbox1;
   GtkWidget *tree1;
+  GtkWidget *button;
   GtkWidget *scrolled1;
   GtkTreeSelection *selection;
   GKB *gkb = pbi->gkb;
@@ -377,13 +393,18 @@ gkb_prop_map_add (GkbPropertyBoxInfo * pbi)
 						GTK_DIALOG_DESTROY_WITH_PARENT,
 						GTK_STOCK_HELP, GTK_RESPONSE_HELP,
 						GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
-						GTK_STOCK_ADD, 100,
 						NULL);
+
+  button = gtk_dialog_add_button (GTK_DIALOG (gkb->addwindow), GTK_STOCK_ADD, 100);
+  gtk_widget_set_sensitive (button, FALSE);
+  
   gtk_dialog_set_default_response (GTK_DIALOG (gkb->addwindow), 100);
   gtk_window_set_screen (GTK_WINDOW (gkb->addwindow),
 			 gtk_widget_get_screen (gkb->applet));
   gtk_object_set_data (GTK_OBJECT (gkb->addwindow), "addwindow",
 		       gkb->addwindow);
+  gtk_object_set_data (GTK_OBJECT (gkb->addwindow), "addbutton",
+		       button);
   
   vbox1 = GTK_DIALOG (gkb->addwindow)->vbox;
   gtk_widget_show (vbox1);
@@ -415,6 +436,8 @@ gkb_prop_map_add (GkbPropertyBoxInfo * pbi)
   /* Signal for double clicks or user pressing space */
   g_signal_connect (G_OBJECT (tree1), "button_press_event",
                     G_CALLBACK (row_activated_cb), pbi);
+  g_signal_connect (G_OBJECT (tree1), "cursor_changed",
+                    G_CALLBACK (addbutton_sensitive_cb), pbi);
        
   g_signal_connect (G_OBJECT (gkb->addwindow), "response",
   		    G_CALLBACK (response_cb), pbi);
