@@ -267,8 +267,11 @@ setMixer(gint vol)
 	tvol = (vol << 8) + vol;
 /*g_message("Saving mixer value of %d",tvol);*/
 	ioctl(mixerfd, MIXER_WRITE(mixerchannel), &tvol);
+/* SOUND_MIXER_SPEAKER is output level on Mac, but input level on PC. #96639 */
+#ifdef __powerpc__
 	ioctl(mixerfd, MIXER_WRITE(SOUND_MIXER_SPEAKER), &tvol);
 #endif
+#endif
 #ifdef SUN_API
  	audio_info_t ainfo;
 	AUDIO_INITINFO (&ainfo);
