@@ -425,7 +425,7 @@ void property_show (BonoboUIComponent *uic,
         gtk_box_pack_start(GTK_BOX(vbox1), checkbox, FALSE, FALSE, 0);
 	gtk_widget_show(checkbox);
 
-        label = gtk_label_new_with_mnemonic (_("_General"));
+        label = gtk_label_new(_("General"));
         gtk_widget_show(vbox);
         /*gnome_property_box_append_page( GNOME_PROPERTY_BOX(propwindow), vbox, label);*/
         gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox, label);
@@ -465,7 +465,7 @@ void property_show (BonoboUIComponent *uic,
 	box_add_color(applet, hbox, _("Bac_kground"), COLOR_TEXT_BG);
 	box_add_color(applet, hbox, _("O_utline"), COLOR_TEXT_MID);
 
-	label = gtk_label_new_with_mnemonic(_("C_olors"));
+	label = gtk_label_new(_("Colors"));
 	gtk_widget_show(vbox);
 	gtk_notebook_append_page( GTK_NOTEBOOK(notebook), vbox, label);
 
@@ -551,7 +551,7 @@ void property_show (BonoboUIComponent *uic,
 	gtk_box_pack_end(GTK_BOX(hbox), button, FALSE, FALSE, 0);
 	gtk_widget_show(button);
 #endif
-        label = gtk_label_new_with_mnemonic(_("_Advanced"));
+        label = gtk_label_new(_("Advanced"));
         gtk_widget_show(vbox);
         gtk_notebook_append_page( GTK_NOTEBOOK(notebook), vbox, label);
 
