@@ -724,6 +724,8 @@ panel_menu_path_edit_dialog_new (PanelMenu  *panel_menu,
 					      GTK_STOCK_CLOSE,
 					      GTK_RESPONSE_CLOSE, GTK_STOCK_OK,
 					      GTK_RESPONSE_OK, NULL);
+	gtk_window_set_screen (GTK_WINDOW (dialog),
+			       gtk_widget_get_screen (GTK_WIDGET (panel_menu->applet)));
 
 	box = GTK_DIALOG (dialog)->vbox;
 
